From 6769c5cfccbc42daa2571a2e1101c67849f61921 Mon Sep 17 00:00:00 2001
From: Sean McBride <sean@rogue-research.com>
Date: Wed, 6 Dec 2017 11:57:28 -0500
Subject: [PATCH 1/2] Fixed various spelling mistakes, mostly in comments

---
 fortran/src/H5Pf.c           | 10 +++++-----
 fortran/src/H5Pff.F90        |  2 +-
 fortran/src/H5Rff.F90        |  2 +-
 fortran/test/tH5T.F90        |  2 +-
 hl/test/test_ds.c            |  8 ++++----
 src/H5T.c                    |  2 +-
 src/H5Zscaleoffset.c         |  6 +++---
 src/H5detect.c               |  4 ++--
 tools/h5copy/h5copygentest.c |  2 +-
 tools/h5import/h5import.c    |  4 ++--
 10 files changed, 21 insertions(+), 21 deletions(-)

diff --git a/fortran/src/H5Pf.c b/fortran/src/H5Pf.c
index 3989512..2f031f6 100644
--- a/fortran/src/H5Pf.c
+++ b/fortran/src/H5Pf.c
@@ -2640,7 +2640,7 @@ h5pget_hyper_vector_size_c ( hid_t_f *prp_id , size_t_f *size)
  * INPUTS
  *  parent - property list class identifier
  *  name   - name of the new class
- *  name_len - lenght of the "name" buffer
+ *  name_len - length of the "name" buffer
  * OUTPUTS
  *  class - new class identifier
  * RETURNS
@@ -3417,8 +3417,8 @@ h5pset_family_offset_c ( hid_t_f *prp_id , hsize_t_f *offset)
  *  mem_map - memory mapping array
  *  memb_fapl - property list for each memory usage type
  *  memb_name - array with members names
- *  len - array with the lenght of each name
- *  lenmax - lenght of the name a sdeclared in Fortran
+ *  len - array with the length of each name
+ *  lenmax - length of the name a sdeclared in Fortran
  *  flag - flag allowing partila access when one of the files is missing
  * RETURNS
  *  0 on success, -1 on failure
@@ -3539,12 +3539,12 @@ h5pset_fapl_multi_sc ( hid_t_f *prp_id , int_f *flag)
  *  Call H5Pget_fapl_multi to set multi file dirver
  * INPUTS
  *  prp_id - file_creation property list identifier
- *  lenmax - lenght of the name a sdeclared in Fortran
+ *  lenmax - length of the name a sdeclared in Fortran
  * OUTPUTS
  *  memb_map - memory mapping array
  *  memb_fapl - property list for each memory usage type
  *  memb_name - array with members names
- *  len - array with the lenght of each name
+ *  len - array with the length of each name
  *  flag - flag allowing partila access when one of the files is missing
  * RETURNS
  *  0 on success, -1 on failure
diff --git a/fortran/src/H5Pff.F90 b/fortran/src/H5Pff.F90
index 532ecc6..86a8453 100644
--- a/fortran/src/H5Pff.F90
+++ b/fortran/src/H5Pff.F90
@@ -5315,7 +5315,7 @@ CONTAINS
 !  
 !  expression - buffer to hold transform expression
 !  hdferr     - Error code
-!                 Success:  Actual lenght of the expression
+!                 Success:  Actual length of the expression
 !                           If provided buffer "expression" is 
 !                           smaller, than expression will be 
 !                           truncated to fit into
diff --git a/fortran/src/H5Rff.F90 b/fortran/src/H5Rff.F90
index 7ba91c4..e0724bc 100644
--- a/fortran/src/H5Rff.F90
+++ b/fortran/src/H5Rff.F90
@@ -517,7 +517,7 @@ CONTAINS
 !
 ! Inputs:
 !  dset_id  - identifier of the dataset containing
-!             reference to teh regions
+!             reference to the regions
 !  ref 	    - reference to open
 ! Outputs:
 !  obj_id   - dataspace identifier
diff --git a/fortran/test/tH5T.F90 b/fortran/test/tH5T.F90
index efbceea..c3fd52b 100644
--- a/fortran/test/tH5T.F90
+++ b/fortran/test/tH5T.F90
@@ -100,7 +100,7 @@ CONTAINS
      INTEGER :: class ! Datatype class
      INTEGER :: num_members ! Number of members in the compound datatype
      CHARACTER(LEN=256) :: member_name
-     INTEGER :: len ! Lenght of the name of the compound datatype member
+     INTEGER :: len ! length of the name of the compound datatype member
      INTEGER :: member_index ! index of the field
      INTEGER(HSIZE_T), DIMENSION(3) :: array_dims=(/2,3,4/)
      INTEGER :: array_dims_range = 3
diff --git a/hl/test/test_ds.c b/hl/test/test_ds.c
index 47929e6..9c10a62 100644
--- a/hl/test/test_ds.c
+++ b/hl/test/test_ds.c
@@ -3075,7 +3075,7 @@ static int test_simple(void)
 
 
     /*-------------------------------------------------------------------------
-    * get the label using a static buffer smaller than the string lenght
+    * get the label using a static buffer smaller than the string length
     *-------------------------------------------------------------------------
     */
 
@@ -3113,7 +3113,7 @@ static int test_simple(void)
     *-------------------------------------------------------------------------
     */
 
-    /* get the lenght of the scale name (pass NULL in name) */
+    /* get the length of the scale name (pass NULL in name) */
     if((name_len=H5DSget_scale_name(dsid,NULL,(size_t)0)) < 0)
         goto out;
 
@@ -3146,7 +3146,7 @@ static int test_simple(void)
         goto out;
 
     /*-------------------------------------------------------------------------
-    * get the scale name using a static buffer smaller than the string lenght
+    * get the scale name using a static buffer smaller than the string length
     *-------------------------------------------------------------------------
     */
 
@@ -4920,7 +4920,7 @@ static int test_errors2(void)
     hsize_t dimd[2]  = {3,3};                 /* size of data dataset */
     hsize_t dims[1]  = {3};                   /* size of scale dataset */
     char    lbuf[255];                        /* label buffer */
-    ssize_t label_len;                        /* label lenght */
+    ssize_t label_len;                        /* label length */
     int     scale_idx;                        /* scale index */
     int     nscales;                          /* number of scales in DIM */
     int     count;                            /* visitor data */
diff --git a/src/H5T.c b/src/H5T.c
index b2575d5..ee7fc9e 100644
--- a/src/H5T.c
+++ b/src/H5T.c
@@ -3686,7 +3686,7 @@ done:
  *
  * Return:	Success:	non-negative
  *
- *		Failure:	nagative
+ *		Failure:	negative
  *
  * Programmer:	Robb Matzke
  *              Tuesday, December 22, 1998
diff --git a/src/H5detect.c b/src/H5detect.c
index 94e841e..f2b5a41 100644
--- a/src/H5detect.c
+++ b/src/H5detect.c
@@ -41,7 +41,7 @@ static const char *FileHeader = "\n\
  *
  *		Detects machine byte order and floating point
  *		format and generates a C source file (H5Tinit.c)
- *		to describe those paramters.
+ *		to describe those parameters.
  *
  * Assumptions: We have an ANSI compiler.  We're on a Unix like
  *		system or configure has detected those Unix
@@ -69,7 +69,7 @@ static const char *FileHeader = "\n\
 /* Define H5SETJMP/H5LONGJMP depending on if sigsetjmp/siglongjmp are */
 /* supported. */
 #if defined(H5_HAVE_SIGSETJMP) && defined(H5_HAVE_SIGLONGJMP)
-/* Always save blocked signals to be restore by siglongjmp. */
+/* Always save blocked signals to be restored by siglongjmp. */
 #define H5JMP_BUF	sigjmp_buf
 #define H5SETJMP(buf)	HDsigsetjmp(buf, 1)
 #define H5LONGJMP(buf, val)	HDsiglongjmp(buf, val)
diff --git a/tools/h5copy/h5copygentest.c b/tools/h5copy/h5copygentest.c
index 7669702..d5121cb 100644
--- a/tools/h5copy/h5copygentest.c
+++ b/tools/h5copy/h5copygentest.c
@@ -228,7 +228,7 @@ static void gent_compressed(hid_t loc_id)
 /*-------------------------------------------------------------------------
  * Function:    gent_named_vl
  *
- * Purpose:     Generate a variable lenght named datatype for a dataset in
+ * Purpose:     Generate a variable length named datatype for a dataset in
                 LOC_ID
  *
  *-------------------------------------------------------------------------
diff --git a/src/H5Zscaleoffset.c b/src/H5Zscaleoffset.c
index 91a6c00..f32f454 100644
--- a/src/H5Zscaleoffset.c
+++ b/src/H5Zscaleoffset.c
@@ -1105,13 +1105,13 @@ H5Z_filter_scaleoffset(unsigned flags, size_t cd_nelmts, const unsigned cd_value
     unsigned char *outbuf = NULL;   /* pointer to new output buffer */
     unsigned buf_offset = 21;       /* buffer offset because of parameters stored in file */
     unsigned i;                     /* index */
-    parms_atomic p;                 /* paramters needed for compress/decompress functions */
+    parms_atomic p;                 /* parameters needed for compress/decompress functions */
 
     FUNC_ENTER_NOAPI_NOINIT
 
     /* check arguments */
     if(cd_nelmts != H5Z_SCALEOFFSET_TOTAL_NPARMS)
-	HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, 0, "invalid scaleoffset number of paramters")
+	HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, 0, "invalid scaleoffset number of parameters")
 
     /* Check if memory byte order matches dataset datatype byte order */
     switch(H5T_native_order_g) {
@@ -1182,7 +1182,7 @@ H5Z_filter_scaleoffset(unsigned flags, size_t cd_nelmts, const unsigned cd_value
         minbits = (uint32_t)scale_factor;
     }
 
     /* prepare paramters to pass to compress/decompress functions */
     p.size = cd_values[H5Z_SCALEOFFSET_PARM_SIZE];
     p.mem_order = H5T_native_order_g;
 
@@ -1182,7 +1182,7 @@ H5Z_filter_scaleoffset(unsigned flags, size_t cd_nelmts, const unsigned cd_value
     }
 
-    /* prepare paramters to pass to compress/decompress functions */
+    /* prepare parameters to pass to compress/decompress functions */
     p.size = cd_values[H5Z_SCALEOFFSET_PARM_SIZE];
     p.mem_order = H5T_native_order_g;
diff --git a/tools/h5import/h5import.c b/tools/h5import/h5import.c
index d1aab0c..83cf5e4 100644
--- a/tools/h5import/h5import.c
+++ b/tools/h5import/h5import.c
@@ -1316,7 +1316,7 @@ static int processConfigurationFile(char *infile, struct Input *in)
     const char *err14a = "COMPRESSION-PARAM keyword appears twice in %s.\n";
     const char *err14b = "Error in retrieving the compression parameter from %s.\n";
     const char *err15a = "EXTERNAL-STORAGE keyword appears twice in %s.\n";
-    const char *err15b = "Error in retrieving the external storage paramters from %s.\n";
+    const char *err15b = "Error in retrieving the external storage parameters from %s.\n";
     const char *err16a = "MAXIMUM-DIMENSIONS keyword appears twice in %s.\n";
     const char *err16b = "MAXIMUM-DIMENSIONS cannot appear before DIMENSION-SIZES are provided.\n";
     const char *err16c = "Error in retrieving the maximum dimension sizes from %s.\n";
@@ -3310,7 +3310,7 @@ static int getCompressionParameter(struct Input *in, FILE *strm)
 {
     /*  currently supports only GZIP */
     /*  can be extended by adding more values to COMPRESSION-TYPE and */
     /*  handling the paramters here by adding more cases  */
 
     int         ival;
     const char *err1 = "Unable to get integer value.\n";
@@ -3310,7 +3310,7 @@ static int getCompressionParameter(struct Input *in, FILE *strm)
     /*  currently supports only GZIP */
     /*  can be extended by adding more values to COMPRESSION-TYPE and */
-    /*  handling the paramters here by adding more cases  */
+    /*  handling the parameters here by adding more cases  */
 
     int         ival;
-- 
2.10.1 (Apple Git-78)

